@@ -12,11 +12,10 @@ get '/oembed' => sub {
   my $url = $c->param('url');
 
   if ($c->stash('restricted') and !grep { $_ eq $url } @{$c->stash('predefined')}) {
-    $c->render(json => {error => "LINK_EMBEDDER_RESTRICTED is set."});
-  }
-  else {
-    $c->embedder->serve($c);
+    return $c->render(json => {error => "LINK_EMBEDDER_RESTRICTED is set."});
   }
+
+  $c->embedder->serve($c);
 };
 
 app->defaults(
@@ -50,6 +49,12 @@ app->defaults(
   ]
 );
 
+$ENV{X_REQUEST_BASE} and hook before_dispatch => sub {
+  my $c = shift;
+  return unless my $base = $c->req->headers->header('X-Request-Base');
+  $c->req->url->base(Mojo::URL->new($base));
+};
+
 app->start;
 
 __DATA__
